@@ -13,7 +13,7 @@ import warnings
 warnings.filterwarnings("ignore")
 
 
-__version__ = '0.6.8'
+__version__ = '0.6.9'
 
 """
 Copyright 2018, Alexander J. Tarashansky, All rights reserved.
@@ -705,17 +705,15 @@ class SAM(object):
 
         Parameters
         ----------
-        genes - numpy.array or list
-            Genes for which contribution to each PC will be calculated.
+        genes - numpy.array or list, default None
+            Genes for which contribution to each PC will be calculated. Set to None 
+            if you know ahead of time which PC you wish to remove from the data using
+            'regress_genes'.
 
         npcs - int, optional, default None
             How many PCs to calculate when computing PCA of the filtered and
             log-transformed expression data. If None, calculate all PCs.
 
-        plot - bool, optional, default False
-            If True, plot the scores reflecting how correlated each PC is with
-            genes of interest. Otherwise, do not plot anything.
-
         Returns:
         -------
         x - numpy.array
@@ -1085,7 +1083,6 @@ class SAM(object):
         sc.pp.neighbors(self.adata,use_rep=use_rep,n_neighbors=k,
                                        metric=distance,method=method)
         sc.tl.diffmap(self.adata, n_comps=n_comps)
-
         sc.pp.neighbors(self.adata,use_rep='X_diffmap',n_neighbors=k,
                         metric='euclidean',method=method)
 
@@ -1107,8 +1104,8 @@ class SAM(object):
         distance = self.run_args.get('distance','correlation')
         sc.pp.neighbors(self.adata,use_rep=use_rep,n_neighbors=k,
                                        metric=distance,method=method)
-        sc.tl.diffmap(self.adata, n_comps=n_comps)
-
+        sc.tl.diffmap(self.adata, n_comps=n_comps+1)
+        self.adata.obsm['X_diffmap'] = self.adata.obsm['X_diffmap'][:,1:]
 
     def density_clustering(self, X=None, eps=1, metric='euclidean', **kwargs):
         from sklearn.cluster import DBSCAN
