@@ -10,7 +10,7 @@ import pandas as pd
 from ipyevents import Event
 from ipywidgets import Widget
 
-__version__ = '0.6.8'
+__version__ = '0.6.9'
 
 class SAMGUI(object):
 
@@ -109,7 +109,7 @@ class SAMGUI(object):
             if 'X_umap' in projs:
                 p = 'X_umap'
             elif len(projs) > 1:
-                p = np.array(projs)[np.where(np.array(projs)!='X_pca')[0]]
+                p = np.array(projs)[np.where(np.array(projs)!='X_pca')[0][0]]
             else:
                 p = 'X_pca'
 
@@ -359,16 +359,16 @@ class SAMGUI(object):
         return pp
 
     def load_ann(self,event):
-        path = self.pp_box.children[7].children[1].value
+        path = self.pp_box.children[6].children[1].value
         try:
             for i in range(len(self.stab.children)):
-                self.sams[i].load_annotations(path)
+                self.sams[i].load_obs_annotations(path)
                 self.update_dropdowns(i)
         except:
             with self.out:
                 print('Annotation file not found or was improperly formatted.')
     def load_vann(self,event):
-        path = self.pp_box.children[8].children[1].value
+        path = self.pp_box.children[7].children[1].value
         try:
             for i in range(len(self.stab.children)):
                 self.sams[i].load_var_annotations(path)
@@ -395,7 +395,7 @@ class SAMGUI(object):
         if not self.SAM_LOADED:
             path = self.SamPlot.children[1].children[0].children[1].value
         else:
-            path = self.pp_box.children[6].children[1].value
+            path = self.pp_box.children[5].children[1].value
 
         filetype = path.split('.')[-1]
         if filetype == 'gz':
@@ -439,11 +439,11 @@ class SAMGUI(object):
 
     def set_pp_defaults(self,event):
         self.preprocess_args = self.preprocess_args_init.copy()
-        fgenes = self.pp_box.children[1].children[1] # checkbox
-        norm = self.pp_box.children[2]
-        sumnorm = self.pp_box.children[3]
-        expr_thr = self.pp_box.children[4].children[1] # expr_threshold
-        min_expr = self.pp_box.children[5].children[1] # min_expr
+        fgenes = self.pp_box.children[0].children[1] # checkbox
+        norm = self.pp_box.children[1]
+        sumnorm = self.pp_box.children[2]
+        expr_thr = self.pp_box.children[3].children[1] # expr_threshold
+        min_expr = self.pp_box.children[4].children[1] # min_expr
 
         init = self.preprocess_args.get('min_expression',1)
         min_expr.set_trait('value',init)
@@ -640,9 +640,7 @@ class SAMGUI(object):
         proj.observe(self.proj_update,'value')
 
         rs = widgets.VBox([widgets.HBox([runb,title]),
-                           widgets.HBox([dfts,wpca]),
-                           widgets.HBox([l1,ngenes]),
-                           widgets.HBox([l2,npcs]),
+                           widgets.HBox([dfts]),
                            widgets.HBox([l3,knn]),
                            widgets.HBox([l4,nna]),
                            norm,
@@ -658,29 +656,29 @@ class SAMGUI(object):
         #,knn
         #,nna
         #norm,dist,proj
-        wpca = self.rs_box.children[1].children[1]
-        ngenes = self.rs_box.children[2].children[1]
-        npcs = self.rs_box.children[3].children[1]
-        knn = self.rs_box.children[4].children[1]
-        nna = self.rs_box.children[5].children[1]
-        rnorm = self.rs_box.children[6]
-        dist = self.rs_box.children[7]
-        proj = self.rs_box.children[8]
+        #wpca = self.rs_box.children[1].children[1]
+        #ngenes = self.rs_box.children[2].children[1]
+        #npcs = self.rs_box.children[3].children[1]
+        knn = self.rs_box.children[2].children[1]
+        nna = self.rs_box.children[3].children[1]
+        rnorm = self.rs_box.children[4]
+        dist = self.rs_box.children[5]
+        proj = self.rs_box.children[6]
 
         init = self.run_args.get('num_norm_avg',50)
         nna.set_trait('value',init)
         init = self.run_args.get('k',20)
         knn.set_trait('value',init)
 
-        init = self.run_args.get('npcs',150)
-        if init is None:
-            init = 150;
-        npcs.set_trait('value',init)
+        #init = self.run_args.get('npcs',150)
+        #if init is None:
+        #    init = 150;
+        #npcs.set_trait('value',init)
 
-        init = self.run_args.get('n_genes',3000)
-        if init is None:
-            init = 3000;
-        ngenes.set_trait('value',init)
+        #init = self.run_args.get('n_genes',3000)
+        #if init is None:
+        #    init = 3000;
+        #ngenes.set_trait('value',init)
 
         init = self.run_args.get('preprocessing','Normalizer')
         if init is None:
@@ -691,9 +689,9 @@ class SAMGUI(object):
         init = self.run_args.get('projection','umap')
         proj.set_trait('value',init)
 
-        init = self.run_args.get('weight_PCs',True)
-        wpca.set_trait('value',init)
-        self.run_args['weight_PCs'] = init
+        #init = self.run_args.get('weight_PCs',True)
+        #wpca.set_trait('value',init)
+        #self.run_args['weight_PCs'] = init
 
     def weightpcs(self,event):
         t = self.run_args.get('weight_PCs',True)
@@ -985,7 +983,7 @@ class SAMGUI(object):
             max=0,
             step=0.05,
             disabled=False,
-            continuous_update=True,
+            continuous_update=False,
             orientation='horizontal',
             readout=True,
             description = '',
@@ -1037,7 +1035,7 @@ class SAMGUI(object):
             max=1,
             step=0.01,
             disabled=False,
-            continuous_update=True,
+            continuous_update=False,
             orientation='horizontal',
             readout=True,
             readout_format='2f',
@@ -1058,7 +1056,7 @@ class SAMGUI(object):
             max=20,
             step=0.1,
             disabled=False,
-            continuous_update=True,
+            continuous_update=False,
             orientation='horizontal',
             readout=True,
             readout_format='2f',
