@@ -13,11 +13,12 @@ from SAM import SAM
 if __name__ == '__main__':
 
     sam = SAM()
-    sam.load_data('example_data/GSE74596_data.csv.gz')
-    sam.load_annotations('example_data/GSE74596_ann.csv')
+    sam.load_data('example_data/darmanis_data.csv.gz')
+    sam.load_obs_annotations('example_data/darmanis_ann.csv')
     sam.preprocess_data()
     sam.run(projection=None)
     sam.run_umap()
     sam.run_tsne()
     sam.kmeans_clustering(4)    
     sam.identify_marker_genes_ratio();
+    sam.identify_marker_genes_rf();
